Monty Python's Flying Circus: Just the Words - Episode 37

# Episode Thirty-seven

'Boxing tonight' - Jack Bodell v. Kenneth Clark
Dennis Moore
What the stars foretell
Doctor
'TV4 or not TV4' diskussion
Lupins
Ideal Loon Exhibition
Off-Licence
Dennis Moore: Stealing from the poor
'Prejudice'
Dennis Moore: Redistibuting the wealth

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| A floodlit boxing ring. Sports programme music.
| SUPERIMPOSED CAPTION: 'BOXING TONIGHT'
Voice Over | 'Boxing Tonight' comes from the Empire Pool, Wembley and features the main heavyweight bout between Jack Bodell, British and Empire Heavyweight Champion. (cheers; shot of Bodell in his corner with two seconds) And Sir Kenneth Clark ... (shot of Clark's corner; he is in a dressing-gown with 'Sir Kenneth Clark' on the back; both take off their dressing-gowns as referee calls them together; Sir Kenneth is wearing a tweed suit underneath) It's the first time these two have met so there should be some real action tonight...
| The bell goes. Crowd noise. Sir Kenneth wanders around as in 'Civilization'.
Sir Kenneth | This then is the height of the English Renaissance, the triumph of Classical over Gothic ... the ...
| Bodell swing a left and knocks Sir Kenneth down.
Voice Over | He's down! Sir Kenneth Clark is down in eight seconds. But he's up again. He's up at six...
Sir Kenneth | The almost ordered facades of Palladio's villas reflects the...
| Boddell knocks him down again.
Voice Over | And he's down again, and I don't think he's going to get up this time. (referee counts Sir Kenneth Clark out and holds up Bodel's hand) No, so Jack Bodel has defeated Sir Kenneth Clark in the very first round here tonight and so this big Lincolnshire heavyweight becomes the new Oxford Professor of Fine Art.
| Zoom in to the ring. The announcer appears in DJ and takes a mike lowered on a wire.
Announcer | Thank you, thank you, thank you, ladies and gentlemen. And now...
| Cut to a corner of the ring. The nude organist at his organ, plays a chord, turns and grins. Cut to the opposite corner; the 'It's' man on his stool.
It's Man | It's...
| Animated titles. Slow pan across idyllic countryside. We see a traditional eighteenth-century coach and horses travelling along the valley floor. Suddenly a highwayman, Dennis Moore, spurs his horse forward and rides up to the coach brandishing pistols.
Moore | Stand and deliver! Drop that gun! (the coach comes to a halt; the drivers hold up their hands but a postillion reaches for a gun; Moore shoots him) Let that be a warning to you all. You move at your peril, for I have two pistols here. I know one of them isn't loaded any more, but the other one is, so that's one of you dead for sure...or just about for sure anyway. It certainly wouldn't be worth your while risking it because I'm a very good shot. I practice every day...well, not absolutely every day, but most days in the week...I expect I must practice, oh, at least four or five times a week at least...at least four or five, only some weekends...like last weekend, there really wasn't the time, so that moved the average down a bit...but I should say it's definitely a solid four days' practice a week...at least. I mean...I reckon I could hit that tree over there...the one just behind that hillock...not the big hillock, the little hillock on the left. (heads are coming out of the coach and peering) You see the three trees, the third from the left and back a bit - that one - I reckon I clould hit that four times out of five...on a good day. Say with this wind...say, say, seven times out of ten...
Squire | What, that tree there?
Moore | Which one?
Squire | The big beech with the sort of bare branch coming out of the top left.
Moore | No, no, no, not that one.
Girl | No, no, he means the one over there. Look, you see that one.
Squire | Yes.
Girl | Well now, go two along to the right.
Coachman | Just near that little bush.
Girl | Well, it's the one just behind it.
Squire | Ah! The elm.
Moore | No, that's not an elm. An elm's got sort of great clumps of leaves like that. That's either a beech or a...er...hornbeam.
Parson | A hornbeam?
Moore | Oh, no not a hornbeam, What's the tree that has a leaf with sort of regular veins coming out and the veins go all the way out to the...
Girl | Serrated?
Moore | ...to the serrated edges.
Parson | A willow!
Moore | That's right.
Parson | That's nothing like a willow.
Moore | Well it doesn't matter, anyway. I can hit it seven times out of ten, that's the point.
Parson | Never a willow.
Moore | Shut up! This is a hold-up, not a botany lesson. Right, now my fine friends, no false moves please. I want you to hand over all the lupins you've got.
Squire | Lupins?
Moore | Yes, lupins. Come on, come on.
Parson | What do you mean, lupins?
Moore | Don't try to play for time.
Parson | I'm not, you mean the flower lupin?
Moore | Yes, that's right.
Squire | Well, we haven't got any lupins.
Girl | Honestly.
Moore | Look, my fine friends. I happen to know that this is the Lupin Express.
Squire | You must be out of your tiny mind.
Moore | Get out of the coach. Come on, get out! (they do so indicating that Moore is a loony; he dismounts and enters the coach; he immediately comes out with an enormous armful of lupins) Just as I thought. Not clever enough, my fine friends. Come on, Concorde. (he jumps on horse and rides away)
Squire | Well, so much for the lupins.
| Montage of Dennis Moore, galloping through the sun-dappled glades, a little village, more glades and forrest and arriving at a little peasant-type woodcutter's hut where two terribly poor peasants greet him and recieve the lupins with a neutral reaction. During this the following song is heard.
Song | Dennis Moore, Dennis Moore, Galloping through the sward, Dennis Moore, Dennis Moore, And his horse Concorde. He steals from the rich and Gives to the poor. Mr Moore, Mr Moore, Mr Moore.
Moore | Here we are, I'll be back.
| Moore wheels round and rides off.
| SUPERIMPOSED CAPTION: 'THE END'
| Pull back to reveal 'The End' is on TV in the house of Mrs Trepidatious. Another old ratbag enters and sits opposite Mrs Trepidatious.
Mrs O | Morning, Mrs Trepidatious.
Mrs Trepidatious | Oh, I don't know what's good about it, my right arm's hanging off something awful.
Mrs O | Oh, you want to have that seen to.
Mrs Trepidatious | What, by that Dr Morrison? He's killed more patients than I've had severe boils.
Mrs O | What do the stars say?
Mrs Trepidatious | Well, Petula Clark says burst them early, but David Frost...
Mrs O | No, the stars in the paper, you cloth-eared heap of anteater's catarrh, the zodiacal signs, the horoscopic fates, the astrological portents, the omens, the genethliac prognostications, the mantalogical harbingers, the vaticinal utterances, the fatidical premonitory uttering of the mantalogical omens - what do the bleeding stars in the paper predict, forecast, prophesy, foretell, prognosticate...
| A big sheet is lowered with the words on.
Voice Over | And this is where you at home can join in.
Mrs O | ... forebode, bode, augur, spell, foretoken, (the audience joins in) presage, portend, foreshow, foreshadow, forerun, herald, point to, betoken, indicate!
Mrs Trepidatious | I don't know.
| The sheet is raised again.
Mrs O | What are you?
Mrs Trepidatious | I'm Nesbitt.
Mrs O | There's not a zodiacal sign called Nesbitt...
Mrs Trepidatious | All right, Derry and Toms.
Mrs O | (surveying paper) Aquarius, Scorpio, Virgo, Derry and Toms. April 29th to March 22nd. Even dates only.
Mrs Trepidatious | Well what does it presage?
Mrs O | You have green, scaly skin, and a soft yellow underbelly with a series of fin-like ridges running down your spine and tail. Although lizardlike in shape, you can grow anything up to thirty feet in length with huge teeth that can bite off great rocks and trees. You inhabit arid sub-tropical zones and wear spectacles.
Mrs Trepidatious | It's very good about the spectacles.
Mrs O | It's amazing.
Mrs Trepidatious | Mm ... what's yours, Irene?
Mrs O | Basil.
Mrs Trepidatious | I'm sorry, what's yours, Basil?
Mrs O | No. That's my star sign, Basil...
Mrs Trepidatious | There isn't a...
Mrs O | Yes there is ... Aquarius, Sagittarius, Derry and Toms, Basil. June 21st to June 22nd.
Mrs Trepidatious | Well, what does it say?
Mrs O | You have green, scaly skin and a series of yellow underbellies running down your spine and tail ...
Mrs Trepidatious | That's exactly the same!
Mrs O | Try number one ... what's Aquarius?
Mrs Trepidatious | It's a zodiacal sign.
Mrs O | I know that, what does it say in the paper Mrs Flan-and-pickle?
Mrs Trepidatious | All right... Oh! It says, 'a wonderful day ahead'. You will be surrounded by family and friends. Roger Moore will drop in for lunch, bringing Tony Curtis with him. In the afternoon a substantial cash sum will come your way. In the evening Petula Clark will visit your home accompanied by Mike Samrues singers. She will sing for you in your own living room. Before you go to bed, Peter Wyngarde will come and declare his undying love for you.
Mrs O | Urghh! What's Scorpio?
Mrs Trepidatious | Oh, that's very good. 'You will have lunch with a schoolfriend of Duane Eddy's, who will insist on whistling some of Duane's greatest instrumental hits. In the afternoon you will die, you will be buried...'
| A doctor is lowered on a wire.
Doctor | Good morning.
Mrs O | Oh, morning, doctor.
Doctor | How's the old arm this morning, Mrs Ikon?
Mrs Trepidatious | Oh, it's still hanging off at the shoulder.
Doctor | Good, well lets have a look at it, shall we? (he tries unsuccessfully to open his bag) Oh damn, damn, damn, damn... damn this wretched bag... oh the wretched, damn, bloody, little bag. It's the one thing I hate about being a doctor - it's this wretched bloody little bag!
| He smashes a chair over it and finally produces a revolver and shoots the lock off. It opens and is stuffed full of pound notes, some of which spill out. He feels inside... eventually pulls out a stethoscope.
Doctor | What's that doing here? (he throws it away)
| Cut to another doctor walking along a street. The stethoscope flies out of window and lands on him.
Second Doctor | (brushing it off) Eurgggh!
| Cut back to the first doctor still rummaging in black bag. Eventually, he produces a pair of black kid gloves and a black handkerchief. He folds it and puts it on and points the gun at Mrs Trepidatious.
Doctor | Hand over the money. (she goes to a sideboard opens the bottom drawer and gets out a money box which she gives to him) Come on, all of it! (she looks scared; he jabs the gun at her; she goes over to a painting of a wall-safe on the wall and pushes it aside to reveal an identical wall-safe underneath. She opens it and a hand comes out holding a money box; she takes and gives it to the doctor) Yes, that seems to be OK. Right! I'll just test your reflexes! (he opens his mac like a flasher; they scream and jump) Right, now then, everything seems to be OK, I'll see you next week. Keep collecting the pensions, and try not to spend too much on food. (he starts to go up)
Mrs Trepidatious | Thank you, doctor. (he disappears)
| Cut to a hospital ward. A man in bed, a chair with his clothes on it at the foot of the bed. A doctor entes and goes right for the jacket and starts to feel in the pockets.
Doctor | Morning, Mr Henson ... How are we today?
Henson | Not too bad, doctor.
Doctor | OK, take it easy ... (he empties his wallet and puts it back) Expecting any postal orders this week?
Henson | No.
Doctor | Righto.
| A nurse comes and gets the loose change. The doctor goes to the next bed where there is a man entirely in traction.
Doctor | Ah, Mr Rodgers, have you got your unemployment benefit please? Right. Well can you write me a cheque then... please?
| The patient writes him a cheque. He goes to the foot of the bed. There is a graph with a money symbol on it. He marks it down further.
Doctor | Thank you very much. Soon have you down to nothing. Ah, Mr Millichope. (he smiles and leaves, passing a man with a saline drip full of coins; chink of money)
| A Gilliam animation suitably connected with the foregoing concept leads us to a TV debate set-up. Stern music starts as the lights come on.
| SUPERIMPOSED CAPTIONS: 'THE GREAT DEBATE' 'NUMBER 31' 'TV4 OR NOT TV4?'
Kennedy | Hello. Should there be another television channel, or should there not? On tonight's programme the Minister for Broadcasting, The Right Honourable Mr Ian Throat MP.
Throat | Good evening.
Kennedy | The Chairman of the Amalgamated Money TV, Sir Abe Sappenheim.
Sappenheim | Good evening.
Kennedy | The Shadow Spokesman for Television, Lord Kinwoodie.
Kinwoodie | Hello.
Kennedy | And a television critic, Mr Patrick Loone.
Loone | Hello.
Kennedy | Gentlemen - should there be a fourth television channel or not? Ian?
Throat | Yes.
Kennedy | Francis.
Kinwoodie | No.
Kennedy | Sir Abe?
Sappenheim | Yes.
Kennedy | Patrick.
Loone | No.
| SUPERIMPOSED CAPTION: 'YES 2 NO 2'
Kennedy | Well there you have it. Two say will, two say won't. We'll be back again next week, and next week's 'Great Debate' will be about Government Interference in Broadcasting and will be cancelled mysteriously.
| The lights fade down. Music.
| SUPERIMPOSED ROLLER CAPTION: 'THE GREAT DEBATE INTRODUCED BY LUDOVIC LUDOVIC WITH SIR ABE SAPPENHEIM IAN THROAT MP LORD KINWOODIE MR PATRICK LOONE'
| Behind this the panel members are seen gesticulating strangely in silhouette. Fade out. Fade up on a picture of Queen Victoria.
Voice Over | Just starting on BBC 1 now, 'Victoria Regina' the inspiring tale of the simple crofter's daughter who worked her way up to become Queen of England and Empress of the Greatest Empire television has ever seen. On BBC 2 now Episode 3 of 'George I' the new 116 part serial about the famous English King who hasn't been done yet. On ITV now the (sound of a punch) Ugh!
| Music starts. Picture of Royal crest.
| SUPERIMPOSED CAPTION: 'GEORGE I'
| The word 'Charles' below the crest has been crossed out and 'George I' written above it.
| CAPTION: 'EPISODE 3 - THE GATHERING STORM'
| This looks very dog-eared and thumb-printed. Cut to studio set of an eighteenth-century ballroom. Some dancing is going on. A fop is talking to two ladies in the usual phony mouthing manner. They laugh meaninglessly.
Grantley | Ah! 'Tis my lord of Buckingham. Pray welcome, Your Grace.
Buckingham | Thank you, Grantley.
Grantley | Ladies, may I introduce to you the man who prophesied that a German monarch would soon embroil this country in continental affairs.
First Lady | Oh, how so, my lord?
Buckingham | Madam, you will recall that prior to his accession our gracious sovereign George had become involved in the long standing Northern War, through his claims to Bremen and Verdun. These duchies would provide an outlet to the sea of the utmost value to Hanover. The Treaty of Westphalia has assigned them to Sweden.
Grantley | In 1648.
Buckingham | Exactly.
Grantley | Meanwhile Frederick William of Denmark, taking advantage of the absence of Charles XII, seized them; 1712.
Second Lady | Oh yes!
First Lady | It all falls into place. More wine?
Grantley | Oh, thank you.
Buckingham | However, just prior to his accession, George had made an alliance with Frederick William of Prussia, on the grounds of party feeling.
Grantley | While Frederick William had married George's only daughter.
First Lady | I remember the wedding.
Buckingham | But chiefly through concern at the concerted action against Charles XII...
| There is a crash as Moore swings through the window on a rope. Everyone gasps and screams. He lands spectacularly.
Moore | Stand and deliver.
All | Dennis Moore!
Moore | The same. And now my lords, my ladies ...your lupins, please.
| General bewilderment and consternation.
Buckingham | Our what?
Moore | Oh, come come, don't play games with me my Lord of Buckingham.
Buckingham | What can you mean?
Moore | (putting pistol to his head) Your life or your lupins, my lord.
| Buckingham and the rest of the gathering now produce lupins which they have secreted about their several persons. They offer them to Moore.
Moore | In a bunch, in a bunch. (they arrange them in a bunch) Thank you my friends, and now a good evening to you all.
| He grabs the rope, is hauled into air and disappears out of the window. There is a bump, a whinny and the sound of galloping hooves. The guests rush to the window to watch him disappear.
Grantley | He seeks them here ... he seeks them there ... he seeks those lupins everywhere. The murdering blackguard! He's taken all our lupins.
First Lady | (produring one from her garter) Not quite.
| Gasps of delight.
Buckingham | Oh you tricked him!
Man | We still have one! (they all cheer)
| Cut to a similar montage as before of Moore galloping through forest, clearings and tiny villages. Song as follows.
Song | Dennis Moore, Dennis Moore, Riding through the night. Soon every lupin in the land Will be in his mighty hand He steals them from the rich And gives them to the poor Mr Moore, Mr Moore, Mr Moore.
| Towards the end of this he arrives at the same peasant's cottage as before, dismounts and runs to the cottage door. He pauses. From inside the cottage we hear quiet moaning. Cut to inside the cottage. In this rude hut, lit by a single candle, the female peasant lies apparently dying on a bunk. Lupins are everywhere, in the fire, on the bed, a large pile of them forms a pillow. The female peasant is moaning and the male peasant is kneeling beside her offering her a lupin. Moore enters slowly.
Male Peasant | (dressed largely in a lupin suit) Try and eat some, my dear. It'll give you strength. (Dennis Moore reverently approaches the bed; the male peasant looks round and sees him) Oh Mr Moore, Mr Moore, she's going fast.
Moore | Don't worry, I've... I've brought you something.
Male Peasant | Medicine at last?
Moore | No.
Male Peasant | Food?
Moore | No.
Male Peasant | Some blankets perhaps... clothes... wood for the fire...
Moore | No. Lupins!
Male Peasant | (exploding) Oh Christ!
Moore | (astonished) I thought you liked them.
Male Peasant | I'm sick to bloody death of them.
Female Peasant | So am I.
Male Peasant | She's bloody dying and all you bring us is lupins. All we've eaten mate for the last four bleeding weeks is lupin soup, roast lupin, steamed lupin, braised lupin in lupin sauce, lupin in the basket with sauted lupins, lupin meringue pie, lupin sorbet... we sit on lupins, we sleep in lupins, we feed the cat on lupins, we burn lupins, we even wear the bloody things!
Moore | Looks very smart.
Male Peasant | Oh shut up! We're sick to death with the stench of them. (sound of a miaow and then a bump) Look. The cat's just choked itself to death on them. (we see a dead cat with lupins coming out of its mouth) I don't care if I never see another lupin till the day I die! Why don't you go out and steal something useful!
Moore | Like what?
Male Peasant | Like gold and silver and clothes and wood and jewels and...
Moore | Hang on, I'll get a piece of paper.
| Cut to a montage of shots of Moore riding away from the hut over which we hear the song.
Song | Dennis Moore, Dennis Moore, Dum dum dum the night. Dennis Moore, Dennis Moore, Dum de dum dum plight. He steals dum dum dum And dum dum dum dee Dennis dum, Dennis dee, dum dum dum.
| Cut back to the ballroom to find the same people discussing British history.
Buckingham | This, coupled with the presence of Peter and his Prussians at Mecklenburg and Charles and his Swedes in Pomerania, made George and Stanhope eager to come to terms with France.
Grantley | Meanwhile, a breach had now opened with...
| Moore swings in as before.
Grantley | Oh no, not again.
Buckingham | Come on.
Moore | Stand and deliver again! Your money, your jewellery, your ... hang on. (he takes out a list) Your clothes, your snuff, your ornaments, your glasswear, your pussy cats...
Buckingham | (aside to the first lady) Don't say anything about the lupins...
Moore | Your watches, your lace, your spittoons...
| Cut to a montage pretty much as before but with Moore riding through the glades dragging behind him a really enormous bag marked with 'swag' in very olde English lettering. This bag is about twenty feet long and bumps along the ground behind the horse with the appropriate sound effects to make it sound full of valuable jewels, gold, silver, etc. Song as follows.
Song | Dennis Moore, Dennis Moore, Riding through the woods. Dennis Moore, Dennis Moore With a bag of things. He gives to the poor and he takes from the rich Dennis Moore, Dennis Moore, Dennis Moore.
| As he arrives at the poor peasant's cottage they run out. They all open the bag together to the peasants' enormous and unmeasurable joy.
Moore | Here we are.
| SUPERIMPOSED CAPTION: 'THE END'
| Cut to stock film of people queuing at an exhibition hall.
Voice Over | Well it may be the end of that, but it's certainly far from the end of - well in fact it's the beginning - well not quite the beginning - well certainly nearer the beginning than the end - well yes damn it, it is to all intents and purposes the beginning of this year's Ideal Loon Exhibition, sponsored by the 'Daily Express'. (cut to interior of hall, people pouring through the doors; above their heads it says 'Ideal Loon Exhibition) Numbskulls and boobies from all over the country have been arriving to go through their strange paces before a large paying crowd. This is the fifteenth Ideal Loon Exhibition and we took a good look round after it was opened by its patron ... (quick flash of Edward Heath opening something) There's Kevin Bruce the digger duffer from down-under, who's ranked fourteenth in the world's silly positions league... (Kevin is in a roped-off exhibition area; with a number in front of him; people are walking past looking at him with programmes; he is dressed in Australian bush gear and he is leaning his forehead against a goldfish bowl on a four-foot-six plinth) This kind of incoherent behaviour is really beginning to catch on down-under. There's Norman Kirby from New Zealand, whose speciality is standing behind a screen with a lady with no clothes on ... (again in an exhibition stand with a number in front; there is a screen which is higher than their heads, but it is cut off at knee height so you can see two pairs of legs, one female, totally bare, one male wearing some enormous boots, no socks) In real life, Norman is a gynaecologist, but this is his lunch hour. And from France there's a superb exhibition of rather silly behaviour by the Friends of the Free French Osteopaths. (on the stand five men dressed in Breton berets, striped French shirts, silly moustaches, with baguettes; in unison they make the silly sign, counting the while 'un, deux, trois') They do this over four hundred times a day. Nobody knows why. But for sheer pointless behaviour you've got to admire Brian Broomers, the battling British boy who for two weeks has been suspended over a tin of condemned veal. (quite a crowd watch this; again a roped-off exhibit, Brian (Graham) is suspended from the ceilling by two car tyres; he lies there smoking a pipe; underneath him there is a small opened tin, with 'veal' on the side) Always popular with the crowd, is the Scotsman with Nae Trews exhibit, and this year's no exception. (a very large man (John) dressed as a Scotsman in front of a sign saying 'Scotsman with Nae Trews Exhibit, Sponsored by Natural Gas'; an enormously long line of middle-aged pepperpots stand waiting in a queue; eath in turn lifts up a comer of Scotsman's kilt, has a tiny peek and walks off) Sponsored by Natural Gas and Glasgow City Council, this exhibit is entirely supported by voluntary contributions. But for a truly magnificent waste of time you've got to go no further than the exhibit from Italy - Italian priests in custard, discussing vital matters of the day. (four Italian priests standing up to their chests in a large vat of custard; in front of them it says 'Italian Priests in custard'; they are animatedly discussing vital matters; hung behind them is a sign saying 'Italy, Land of Custard') These lads from a seminary near Cremona, have been practising for well over a year. As always one of the great attractions of this fourteen-day exhibition is the display of counter-marching given by the Massed Pipes and Toilet Requisites of the Colwyn Bay Massed Pipes and Toilet Requisites Club. (a dozen people in blazers, flannels and white pumps are vigorously counter-marching, whilst Souza's Star Spangled Banner blares out; they are holding various items of plumbing, lengths of piping, a toilet, a bidet, a bath, back scrubbers, loofahs, shower attachments, hand basins, etc.) An interesting point about these boys is they all have one thing in common. Hip injuries. Not far away the crowds are flocking to see a member of the famous Royal Canadian Mounted Geese. (cut to pantomime goose on horseback) But the climax of the whole event is the judging.
| Cut to a sort of Miss World cat-walk. A judge appears holding number 41. A band plays 'A pretty girl is like a melody'.
PA Announcement | Mr Justice Burke. (the judge walks down, turns slightly at the edge of the stage, puts a knee forward and makes a cheesecake smile) Well that's the last, and let's just see those last six once again. (the judge on the stage is joined by five others in full judicial robes, with wigs, each holding a number) And the winner is - number 41, Mr Justice Burke.
| The winner reacts by bursting into tears. The others look rather sad. Cut to a still picture of Mr Justice Burke in bed having breakfast the next morning. He is still wearing his robes and wig but he has a sceptre and a terrible tiara crown on. This picture is in black and white and is large on the front page of a newspaper. The headline is 'Justice seen to be done'. A subheading says 'British Justice Triumphs'. This newspaper page takes us off into a couple of minutes of animation. Close up of a man's face.
McGough | Yet fear, not like an aged florin, can so disseminate men's eyes, that fortune, straining at a kissing touch may stop her ceaseless search to sport amidst the rampant thrust of time, and bring the thing undone to pass by that with which the cock may chance an arm.
| Cut to a wider shot to show that he is in an off-licence. Mr Bones is behind the counter.
Mr Bones | Well that's all very well, sir, but this is an off-licence.
McGough | Oh. Just a bottle of sherry then, please.
Mr Bones | Certainly... Amontillado?
McGough | Yes, I think Amontillado, finely grown ... well chosen from the casque of Pluto's hills, cell'd deep within the vinous soil of Spain, wrench'd thence from fiery regions of the sun...
Mr Bones | Yes, yes sir. Just one bottle?
McGough | Just one bottle. Just one jot. Just one tittle. That's the lot.
Mr Bones | There we are, sir. That'll be a pound, please.
McGough | A pound a pound and all around abound A pound found found Lost lost the cost till was't embossed...
Mr Bones | Excuse me, sir.
McGough | Yes, good victualler, nature's trencherman, mine honest tapster...
Mr Bones | I was just wondering. Are you a poet?
McGough | No, no, I'm a solicitor... well versed within the written law of man, we can to those who need...
Mr Bones | Oh shut up.
McGough | I'm sorry. I'm afraid I've caught poetry.
Mr Bones | Oh really? Well, don't worry, sir - I used to suffer from short stories.
McGough | Really? When?
Mr Bones | Oh, once upon a time ... there lived in Wiltshire a young Chap called Dennis Moore. Now Dennis was a highwayman by profession ... (we ripple through to Dennis Moore riding along with a big bag of swag) ... and for several months he had been stealing from the rich to give to the poor. One day...
| Mix through to a shot of Dennis Moore arriving with another bag of goodies. The peasants who greet him are by now very smartly dressed and the cottage has been refurbished.
Moore | Here we are again, Mr Jenkins. (Dennis leaves the bag and wheels his horse around) There we are... I'll be back. (he rides off again purposefuly)
| Cut to ballroom. The walls are bare and the people are down to their undergarments. They sit around the table gnawing pieces of bread and dipping them in a watery soup. The central bowl of soup contains a lupin.
Buckingham | Meanwhile Frederick William bushy engaged in defending against the three great powers the province of Silesia...
Grantley | ... which he had seized in the War of the Austrian succession against his word.
First Lady | Yes, I remember.
Man | ... was now dependent on Pitt's subsidies.
| Moore swings in through the window. They all respond to him with listless moans of disappointment.
Moore | My lords, my ladies, on your feet, please. (he is ignored and therefore says commandingly) I must ask you to do exactly as I say or I shall be forced to shoot you right between the eyes. (they stand up hurriedly) Well not right between the eyes, I mean when I say between the eyes, obviously I don't have to be that accurate, I mean, if I hit you in that sort of area, like that, obviously, that's all right for me, I mean, I don't have to try and sort of hit a point bisecting a line drawn between your pupils or anything like that. I mean, from my point of view, it's perfectly satisfactory...
First Lady | What do you want? Why are you here?
Moore | Why are any of us here? I mean, when you get down to it, it's all so meaningless, isn't it? I mean what do any of us want...
Buckingham | No, no, what do you want now?
Moore | Oh I see, oh just the usual things, a little place of my own, the right girl...
Grantley | No, no, no! What do you want from us?
Moore | Oh sorry. Your gold, your silver, your jewellery.
Buckingham | You've taken it all.
First Lady | This is all we've got left.
Moore | That's nice. I'll have them. Come on. (he takes all the spoons)
Buckingham | You'd better take the bloody lupin too.
Moore | Thank you very much, I've gone through that stage. (he grabs the rope and swings out again)
| Short montage of Dennis riding accompanied by the song. Dennis Moore, Dennis Moore Etcetera, etcetera... He leaps off his horse and runs to the door of the hut, throws the door open and enters. The little hut is now stuffed with all possible signs of wealth and all imaginable treasures.
Male Peasant | What you got for us today then.
Moore | Well I've managed to find you four very nice silver spoons Mr Jenkins.
Male Peasant | (snatching them rudely) Who do you think you are giving us poor this rubbish?
Female Peasant | Bloody silver. Won't have it in the house. (throws it away) And those candlesticks you got us last week were only sixteen carat.
Male Peasant | Yes, why don't you go out and steal something nice like some Venetian silver.
Female Peasant | Or a Velasquez for the outside loo.
Moore | Oh all right. (turns purposefully)
| Usual montage of Dennis Moore riding plus song.
Song | Dennis Moore, Dennis Moore Riding through the land Dennis Moore, Dennis Moore Without a merry band He steals from the poor and gives to the rich Stupid bitch.
| Dennis Moore reins to sudden halt and looks over to camera.
Moore | What did you sing?
Singers | (speaking) We sang... he steals from the poor and gives to the rich.
Moore | Wait a tic ... blimey, this redistribution of wealth is trickier than I thought.
| Women's Institute applause. A church-hall type stage, as if for a TV version of 'Down Your Way '. A vast sign across the backcloth reads 'Prejudice'. Russell Braddon enters. He wears a suit and has a clipboard.
Braddon | Good evening and welcome to another edition of 'Prejudice' - the show that gives you a chance to have a go at Wops, Krauts, Nigs, Eyeties, Gippos, Bubbles, Froggies, Chinks, Yidds, Jocks, Polacks, Paddies and Dagoes. (applause; he goes to desk at side of stage)
| SUPERIMPOSED CAPTION: 'ALL FACTS VERIFIED BY THE RHODESIAN POLICE'
Braddon | Tonight's show comes live from the tiny village of Rabid in Buckinghamshire, and our first question tonight is from a Mrs Elizabeth Scrint who says she is going on a Mediterranean cruise next week and can't find anything wrong with the Syrians. Well, Mrs Scrint, apart from being totally unprincipled left-wing troublemakers, the Syrians are also born skivers, they're dirty, smelly and untrustworthy, and, of course, they're friends of the awful gippos. (applause) There you are, Mrs Scrint, I hope that answers some of your problems - have a nice trip. (more applause) Well now, the result of last week's competition when we asked you to find a derogatory term for the Belgians. Well, the response was enormous and we took quite a long time sorting out the winners. There were some very clever entries. Mrs Hatred of Leicester Said 'let's not call them anything, let's just ignore them' ... (applause starts vigorously, but he holds his hands up for silence) ... and a Mr St John of Huntingdon said he couldn't think of anything more derogatory than Belgians. (cheers and applause; a girl in showgirl costume comes on and holds up placards through next bit) But in the end we settled on three choices: number three ... the Sprouts (placard 'The Sprouts'), sent in by Mrs Vicious of Hastings... very nice ; number two..... the Phlegms (placard) ... from Mrs Childmolester of Worthing; but the winner was undoubtedly from Mrs No-Supper-For-You from Norwood in Lancashire... Miserable Fat Belgian Bastards. (placard; roar of applause) Very good - thank you, Carol. (Carol exits) But as you know on this programme we're not just prejudiced against race or colour, we're also prejudiced against - yes, you've guessed, stinking homosexuals! (applause) So before the streets start emptying in Chelsea tonight, Let's go straight over to our popular prejudiced panel game and invite you once again to - Shoot The Poof! And could our first contestant sign in please.
| Cut to blackboard and entrance as they used to have in 'What's My Line'. A contestant comes from behind screen and starts to write his name.
Voice Over | Our first contestant is a hairdresser from...
| A shot rings out and the contestant falls to the floor. Applause. Cut to a camp highwayman in a pink mask who blows smoke from a gun and puts it back in the holster.
Highwayman | I never did like that kind of person... !
| A shot rings out. He dies. Cut to Dennis Moore on a horse blowing smoke from gun and putting it in his holster. He gallops off. We see him swooping down, after a couple of riding shots, on another stagecoach.
Moore | Halt! Halt! (the stage comes to a halt and the occupants get out rapidly, their hands held high) Gentlemen, ladies, bring out your valuables please. Come along sir, come along. Come along, madam, come along. Oh, is that all you've got ... well, he's got much more than you ... so you'd better have some of his ... (transfers money from one passenger to another, dropping some)... sorry... pick them up in a moment... there's about oh, what, nine down there... so you must have about... oh, he's still got lots... oh you've got what? ... you've got more than he started with... so if I give you some of those (transferring more coins) ... well now, look ... have you got a bit of jewellery? If I give you that one and you have some of his coins (the credits start, superimposed) ... is that another box? Were you trying to hide it? Well, that's nice! Right! Now. I've got a tiara ... you've got one... you've got one of the boxes... you've got one... anyone else got a tiara? Take your hat off! (passenger does so to reveal a tiara)... Oh, honestly, it's absolutely pointless trying to do this if you're going to cheat. It really is awful of you;.. (fade out)
| CAPTION: 'ERRATUM. JACK BODELL WAS BORN IN SWADLINCOTE IN DERBYSHIRE'
| Cut to the inside of a bus. A judge is sitting there in full robes, looking rather unhappy. He is obviously one of the competitors from earlier. His friend tries to cheer him up.
Friend | I thought you should have won. I mean, judicially you swept the board ... all right, he has posture, but where was he in the summing up?
| Behind these two another judge is sitting with his mother, crying.
Mother | Oh shut up Melford, there's always next year.
| Another judge further back petulantly rips up his number card. We cut to the outside back of this bus. The destination board says 'The End'. As the bus drives away we hold on a board sticking out from a building which reads 'Hospital... sorry no cheques'.